@@ -1,7 +1,6 @@
 import faulthandler
 import inspect
 import logging
-import os
 import signal
 import time
 import traceback
@@ -13,11 +12,9 @@ from typing import Callable, Dict, List, NoReturn, TypeVar, Union
 
 from google.protobuf.internal.enum_type_wrapper import EnumTypeWrapper
 from grpc import Server, insecure_channel, server
-
-import grpc_helper
-from grpc_helper.api import ConfigApiVersion
-from grpc_helper.api import Event as RpcEvent
-from grpc_helper.api import (
+from grpc_helper_api import ConfigApiVersion
+from grpc_helper_api import Event as RpcEvent
+from grpc_helper_api import (
     EventApiVersion,
     EventProperty,
     Filter,
@@ -29,12 +26,14 @@ from grpc_helper.api import (
     ResultStatus,
     ServerApiVersion,
     ServiceInfo,
-    ShutdownRequest,
+    ShutdownRequest
 )
-from grpc_helper.api.config_pb2_grpc import ConfigServiceStub, add_ConfigServiceServicer_to_server
-from grpc_helper.api.events_pb2_grpc import EventServiceStub, add_EventServiceServicer_to_server
-from grpc_helper.api.logger_pb2_grpc import LoggerServiceStub, add_LoggerServiceServicer_to_server
-from grpc_helper.api.server_pb2_grpc import RpcServerServiceServicer, RpcServerServiceStub, add_RpcServerServiceServicer_to_server
+from grpc_helper_api.config_pb2_grpc import ConfigServiceStub, add_ConfigServiceServicer_to_server
+from grpc_helper_api.events_pb2_grpc import EventServiceStub, add_EventServiceServicer_to_server
+from grpc_helper_api.logger_pb2_grpc import LoggerServiceStub, add_LoggerServiceServicer_to_server
+from grpc_helper_api.server_pb2_grpc import RpcServerServiceServicer, RpcServerServiceStub, add_RpcServerServiceServicer_to_server
+
+import grpc_helper
 from grpc_helper.client import RpcClient
 from grpc_helper.config.cfg_item import Config
 from grpc_helper.config.cfg_manager import ConfigManager
@@ -46,7 +45,7 @@ from grpc_helper.logs.logs_utils import add_rotating_handler, clean_rotating_han
 from grpc_helper.manager import RpcManager
 from grpc_helper.methods import RpcSimpleMethod, RpcStreamingMethod
 from grpc_helper.static_config import RpcStaticConfig
-from grpc_helper.utils import is_streaming, trace_buffer
+from grpc_helper.utils import is_streaming, is_windows, trace_buffer
 
 # Config file name
 PROXY_FILE = "proxy.json"
@@ -246,8 +245,8 @@ class RpcServer(RpcServerServiceServicer, RpcManager):
         self.logger.debug(f"RPC server started on port {self.__port}")
 
         # Hook debug signal if required
-        if with_debug_signal and os.name == "posix":
-            signal.signal(signal.SIGUSR2, self.__dump_debug)
+        if with_debug_signal and not is_windows():
+            signal.signal(signal.SIGUSR2, self.__dump_debug)  # pragma: no cover
 
         # Load all managers (including client pointing to all served services)
         to_raise = None
@@ -283,8 +282,9 @@ class RpcServer(RpcServerServiceServicer, RpcManager):
         """
 
         # Prepare debug output
-        output = self._log_folder / f"RpcServerDump-{time.strftime('%Y%m%d%H%M%S')}.txt"
-        with output.open("w") as f:
+        # No coverage, as platform specific
+        output = self._log_folder / f"RpcServerDump-{time.strftime('%Y%m%d%H%M%S')}.txt"  # pragma: no cover
+        with output.open("w") as f:  # pragma: no cover
             # Dump threads
             faulthandler.dump_traceback(f, all_threads=True)
 
@@ -385,7 +385,7 @@ class RpcServer(RpcServerServiceServicer, RpcManager):
     def __check_service_names(self, request: Union[ProxyRegisterRequest, Filter]) -> List[ServiceInfo]:
         if any(n not in self.__info for n in request.names):
             raise RpcException("At least one of the required service names is unknown", ResultCode.ERROR_ITEM_UNKNOWN)
-        return list(map(lambda n: self.__info[n], request.names))
+        return [self.__info[n] for n in request.names]
 
     def __check_proxy_names(self, request: Union[ProxyRegisterRequest, Filter]) -> List[ServiceInfo]:
         # Verify input proxy names
